@@ -33,7 +33,7 @@ HEADERS = h4toh5.h H4TOH5api_adpt.h h4toh5vector.h
 
 Including declarations of constant and utility subroutines
 
-Author:  Kent Yang(ymuqun@ncsa.uiuc.edu)
+Author:  Kent Yang(myang6@hdfgroup.org)
  
 
 *****************************************************************************/
@@ -181,6 +181,17 @@ not necessary since image will use PALETTE as the object reference list name, ke
 #define IMAGE_HASHSIZE   128
 #define OBJECT_HASHSIZE  128
 #define NAME_HASHSIZE    64
+
+/* These constants are added to support the use of HDF5 dimension scale APIs. 
+   DIMPURE_HASHSIZE is the size of a hash table to handle the user-defined SDS dimensions 
+   that don't have dimension scales.
+
+   DIMSCALE_HASHSIZE is the size of a hash table to handle the user-defined SDS dimensions
+   that have dimension scales.
+*/ 
+#define DIMPURE_HASHSIZE 8
+#define DIMSCALE_HASHSIZE 8
+
 /* This should be enough to hold a textual representation of reference number.
  * If the reference number is of very long type like 2^128 in the future,
  * this will not be safe */
@@ -242,7 +253,9 @@ extern char str_version[VER_LEN];
  * many elements will be put one chunk. If this number is too big, the file size can
  * be bigger. If this number is too small, this file may suffer from bad performance.
  */
-#define H4H5_DEFAULT_NUMELEM_IN_CHUNK  512
+/*512 is too small, change to 2048 */
+/*#define H4H5_DEFAULT_NUMELEM_IN_CHUNK  512 */
+#define H4H5_DEFAULT_NUMELEM_IN_CHUNK  2048
 
 
 /**********************************************/
@@ -295,7 +308,7 @@ struct error_list{
   struct error_list* next;
 };
 
-/* this struct includeS all hash table information and error 
+/* this struct includes all hash table information and error 
 handling information. This information will be initialized at 
 H4toH5open and be close at H4toH5close. 
 ID handler of HDF5 library will be used.*/
@@ -306,8 +319,10 @@ typedef struct {
   struct table* vg_hashtab;
   struct table* vd_hashtab;
   struct table* pal_hashtab;
+  struct table* fakedim_hashtab;
   struct name_table* name_hashtab;
-  struct name_table* dim_hashtab;
+  struct name_table* puredim_hashtab;
+  struct name_table* dimscale_hashtab;
   struct modname_table* moddim_hashtab;
   struct name_table* h5groupname_table;
   int32 file_id;
@@ -324,6 +339,7 @@ typedef struct {
   void *created_datasets;
   void *manglednames;
   void *eos2data;
+  short has_swath;
 #endif
   hid_t file5_id;
   struct error_list* h4toh5error;
@@ -414,6 +430,12 @@ int h4_transpredattrs(hid_t h4toh5id,hid_t,const char *,char*data);
 int h4_transnumattr(hid_t h4toh5id,hid_t h5g,const char *,uint16
 group_ref);
 
+/* Check if this attr flag is valid.
+ * attr_flag should be between 0 and 4. 
+ * See h4toh5.h for the value representation(H425_NOATTRS etc.)
+ */
+int is_valid_attr_flag(int attr_flag); 
+
 hid_t H5Acreate_safe(hid_t h4toh5id, hid_t loc_id, const char *name, hid_t type_id, hid_t space_id, hid_t acpl_id);
 
 int transattrs_split(hid_t h4toh5id, hid_t enclosing, const char *attrname, hid_t aspace, const char *data, int datalen);
@@ -479,7 +501,10 @@ table is looked up or not)
 2. get_name (obtain the name of the object
 according to the object reference)
  3. set_name (store the name and object reference of the
-object into the reference table) **********/
+object into the reference table) 
+4. get_len_by_name(obtain the length of the Fakedim according to
+the name.)
+                                **********/
 
 int lookup(hid_t h4toh5id,int,int,struct table*,int*); 
 
@@ -487,9 +512,14 @@ int lookup(hid_t h4toh5id,int,int,struct table*,int*);
 
 char* get_name(hid_t,int,int,struct table*,int*);
 int   set_name(hid_t,int,int,struct table *,char*,int); 
+char* lookup_len_update_name(hid_t,int,struct table *,const char*,short*); 
 int   init_tab(hid_t,int,struct table*); 
 int   freetable(int,struct table *);
 
+/* This is for the initalization and freeing of the fakedim table*/ 
+int   init_tab2(hid_t,struct table*); 
+int   freetable2(struct table *);
+
 /********IV(2) 
 table used the object name as the key 
 These functions are:
@@ -521,9 +551,19 @@ int init_modnametab(hid_t h4toh5id,int,struct modname_table*);
 
 /*** PART V MISC. Functions. ****/
 
+/*1. dimension scale functions*/
+#if 0
+#ifdef USE_DIMSCALE_APIS
+hid_t create_pure_fake_dim_scale(hid_t,char*,int,int);
+hid_t create_pure_dim_scale(hid_t,int,int);
+hid_t create_dim_scale(hid_t,int,int);
+#endif
+#endif
+
+/*2. other functions */
 char* get_obj_aboname(hid_t h4toh5id,char*,char*,const char*,const char*,struct name_table*,int,int*);
 int free_allhashmemory(h4toh5id_t*);
-hid_t get_h5groupid(const char*,hid_t);
+hid_t get_h5groupid(const char*,hid_t,int);
 char* get_h5datasetname(hid_t h4toh5id,const char*,const char*,uint16,const char*,int,int*);
 char* get_orih5datasetname(hid_t h4toh5id, uint16,const char*,int);
 
