@@ -20,6 +20,9 @@
 #include <vector>
 #include <string>
 #include <algorithm>
+#ifndef _WIN32
+#include <unistd.h>
+#endif
 
 
 #define suicide()  do { _suicide(__FILE__, __LINE__); _exit(1); } while (0)
